[PATCH] 2.6.16-rc1 HID: changed email



Changed email address of Johann Deneux (myself)
Also removed $$ in comments (no longer using cvs)

Signed-off-by: Johann Deneux <johann.deneux@xxxxxxxxx>

---
commit 160f2f07187e5cb23c5efc02824e1a6a0ad06e4e
tree f990e9969b2e9317bb45d2329b1fce36b415889a
parent dc4756e0d0dcb8c44fc1d93674b4e768d9cfb42f
author Johann Deneux <johann.deneux@xxxxxxxxx> Mon, 23 Jan 2006 23:41:02 +0100
committer Johann Deneux <johann.deneux@xxxxxxxxx> Mon, 23 Jan 2006 23:41:02 +0100


 drivers/usb/input/hid-ff.c   |    4 +---
 drivers/usb/input/hid-lgff.c |    6 ++----
 2 files changed, 3 insertions(+), 7 deletions(-)

diff --git a/drivers/usb/input/hid-ff.c b/drivers/usb/input/hid-ff.c
index 72e6986..19f592d 100644
--- a/drivers/usb/input/hid-ff.c
+++ b/drivers/usb/input/hid-ff.c
@@ -1,6 +1,4 @@
 /*
- * $Id: hid-ff.c,v 1.2 2002/04/18 22:02:47 jdeneux Exp $
- *
  *  Force feedback support for hid devices.
  *  Not all hid devices use the same protocol. For example, some use PID,
  *  other use their own proprietary procotol.
@@ -24,7 +22,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Should you need to contact me, the author, you can do so by
- * e-mail - mail your message to <johann.deneux@xxxxxxxx>
+ * e-mail - mail your message to <johann.deneux@xxxxxxxxx>
  */

 #include <linux/input.h>
diff --git a/drivers/usb/input/hid-lgff.c b/drivers/usb/input/hid-lgff.c
index f82c9c9..07f409f 100644
--- a/drivers/usb/input/hid-lgff.c
+++ b/drivers/usb/input/hid-lgff.c
@@ -1,6 +1,4 @@
 /*
- * $$
- *
  * Force feedback support for hid-compliant for some of the devices from
  * Logitech, namely:
  * - WingMan Cordless RumblePad
@@ -25,7 +23,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Should you need to contact me, the author, you can do so by
  * e-mail - mail your message to <johann.deneux@xxxxxxxx>
  */

 #include <linux/input.h>
@@ -207,7 +205,7 @@ int hid_lgff_init(struct hid_device* hid
 	add_timer(&private->timer);  /*TODO: only run the timer when at least
 				       one effect is playing */

- printk(KERN_INFO "Force feedback for Logitech force feedback devices by Johann Deneux <johann.deneux@xxxxxxxx>\n");
+ printk(KERN_INFO "Force feedback for Logitech force feedback devices by Johann Deneux <johann.deneux@xxxxxxxxx>\n");


 	return 0;
 }
-
@@ -25,7 +23,7 @@
  *
  * Should you need to contact me, the author, you can do so by
- * e-mail - mail your message to <johann.deneux@xxxxxxxx>
+ * e-mail - mail your message to <johann.deneux@xxxxxxxxx>
  */

To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/



Relevant Pages

  • Re: [linux-usb-devel] Re: [HID] Fix hiddev devfs oops
    ... > but I kept postponing it because I wanted to look closer, ... It looks entirely reasonable and my hid devices continue to work, ... Yes that's exactly the situation I'm in (APC UPS via USB) and it does fix ... send the line "unsubscribe linux-kernel" in ...
    (Linux-Kernel)
  • enumerating HID devices
    ... Is there an easy way in Linux to enumerate all HID devices, ... the device node? ... you can't assign IP address 127.0.0.1 to the loopback adapter, ... send the line "unsubscribe linux-kernel" in ...
    (Linux-Kernel)